Benutzereinstellungen — Lino Tera Benutzerhandbuch

# Benutzereinstellungen

## Meine Einstellungen

Jeder Benutzer kann einen Teil seiner Benutzereinstellungen selber bearbeiten. Oben rechts im Hauptmenü steht dein Name. Klicke darauf, um dein Benutzermenü* zu öffnen und wähle dann Meine Einstellungen.

Das Fenster hat drei Reiter:

- Allgemein : Benutzername kann der Systemverwalter ändern.

  - Wenn du Initialien ausfüllst, sehen deine Kollegen das an Stelle deines vollen Namens.

  - Momentan ist zu klären, ob deine Abteilung überhaupt noch benutzt wird.

- Kalender : Standard-Kalenderintragsart

  - Dienstleistungsart : trage hier die Dienstleistungsart eintragen, die Lino beim Erfassen von Terminen standardmässig eintragen soll.

  - Kassenbuch wähle hier dein Kassenbuch aus, falls du bei Terminen Bargeld kassieren möchtest. Jeder Benutzer sollte sein eigenes Kassenbuch haben. Neue Kassenbücher kann man konfiguriereun unter :menuselection: Gebühren

- Dashboard : hier kannst du einstellen, was in deinem Dashboard steht und was nicht, sowie die Reihenfolge der Elemente.

## Passwort ändern

Um dein Passwort zu ändern, öffne das Fenster Meine Einstellungen und klicke dann auf den Button mit dem Asterisk (✱).